SystemOrganization addCategory: #'Seaside-Tests-Development'!

WAContextTestCase subclass: #WADispatcherComponentTest
	instanceVariableNames: 'rootHanlder childHanlder configApplication normalApplication childApplication configComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADispatcherComponentTest methodsFor: 'private' stamp: 'pmm 5/11/2008 22:30'!
handlersToPush
	^super handlersToPush, (Array
		with: configApplication
		with: (WASession new setParent: configApplication; yourself))! !

!WADispatcherComponentTest methodsFor: 'private' stamp: 'lr 9/13/2008 11:40'!
requestContextWithUrl: aString
	^ WARequestContext
		server: self
		request: (WARequest
			method: 'GET'
			url: aString
			headers: Dictionary new
			fields: Dictionary new
			cookies: Array new
			remoteAddress: '127.0.0.1')! !

!WADispatcherComponentTest methodsFor: 'running' stamp: 'MAD 9/13/2008 16:27'!
setUp
	super setUp.
	rootHanlder := WADispatcher named: 'seaside'.
	childHanlder := WADispatcher register: 'child' in: rootHanlder.
	
	configApplication := WAApplication register: 'config' in: rootHanlder.
	configApplication configuration addParent: WARenderLoopConfiguration instance.
	configApplication preferenceAt: #rootClass put: WADispatcherEditor.
	
	normalApplication := WAApplication register: 'counter' in: childHanlder.
	normalApplication configuration addParent: WARenderLoopConfiguration instance.
	normalApplication preferenceAt: #rootClass put: WADispatcherEditor! !

!WADispatcherComponentTest methodsFor: 'testing' stamp: 'lr 9/13/2008 11:40'!
testChildApplication
	| context |
	configComponent := WADispatcherEditor on: rootHanlder.
	
	context := self requestContextWithUrl: '/seaside/config/child/counter'.
	
	configComponent initialRequest: context request.
	self assert: configComponent handler == childHanlder! !

!WADispatcherComponentTest methodsFor: 'testing' stamp: 'lr 9/13/2008 11:41'!
testNestedDispatcher
	| context |
	configComponent := WADispatcherEditor on: rootHanlder.
	context := self requestContextWithUrl: '/seaside/config/child'.
	
	configComponent initialRequest: context request.
	self assert: configComponent handler == childHanlder! !

TestCase subclass: #WADebugErrorHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADebugErrorHandlerTest commentStamp: 'jf 9/19/2008 19:32' prior: 0!
This isn't really a unit test of WADebugErrorHandler but rather a test that tries to replicate a simple version of the same error handling behaviour upon which the error handler depends. The error handler itself would be hard to test because it opens a debugger as its first action.

This should at least help confirm that the assumptions that were in place when writing the handler on Squeak hold true on other platforms.!

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:03'!
handleException: anException debuggerSimulation: debugBlock
	debugBlock ifCurtailed: [^  #aborted].
	anException resume! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:28'!
simulateWithDebugBlock: debugBlock progress: desiredProgress result: desiredResult
	"Set up a known working mechanism similar to the error handler so we can
	test whether the underlying system works the same way as on Squeak
	where WADebugErrorHandler was originally developed."
	
	| progress semaphore result |
	progress := OrderedCollection new.
	
	semaphore := SeasidePlatformSupport semaphoreClass new.
	
	[[ result := [
		progress add: #a.
		1/0.
		progress add: #b.
		#resumed ]
			on: Error
			do: [ :e |
				progress add: #c.
				self
					handleException: e
					debuggerSimulation: [
						progress add: #d.
						debugBlock value.
						progress add: #e ] ]
	] ensure: [ semaphore signal ] ] fork.

	semaphore wait.
	
	self assert: progress asArray = desiredProgress asArray.
	self assert: result = desiredResult.! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:25'!
testMechanismAbort
	"Test if things behave as expected when simulating a Debugger being closed
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [Processor activeProcess terminate]
		progress: #(a c d)
		result: #aborted! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:29'!
testMechanismProceed
	"Test if things behave as expected when simulating a Debugger being proceeded
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [nil]
		progress: #(a c d e b)
		result: #resumed! !
